.. currentmodule:: obspy.clients.seedlink
.. automodule:: obspy.clients.seedlink

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       ~basic_client.Client
       ~easyseedlink.EasySeedLinkClient
       ~slclient.SLClient
       ~slpacket.SLPacket
       ~client.slnetstation.SLNetStation
       ~client.seedlinkconnection.SeedLinkConnection
       ~client.slstate.SLState

    .. comment to end block

    Modules
    -------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       basic_client
       easyseedlink
       slclient
       slpacket
       seedlinkexception
       client.seedlinkconnection
       client.slnetstation
       client.slstate

    .. comment to end block
